
function getPage() {
    var url = window.location.pathname;
    url = url.split("/");
    return url[url.length - 1];
}

/**
 * Because the navigation and footer of this page are loaded a single time and the individual navigation elements
 * load specific content dynamically, we need a couple functions so that the menu navigation still functions as
 * you would expect on mobile devices.
 *
 * This means that we need handlers to make the nav menu collapse once a selection has been made, and also a handler
 * to make sure that clicking the mobile nav button makes the full nav list show (removing the dropdown).
 */

// Close dropdown menu after clicking nav link
$('div.collapse ul.nav li a').each(function () {
    $(this).on("click", function () {
        var $obj = $($(this).parents('.in')[0]);
        $obj.animate({'height': '1px'}, function () {
            $obj.removeClass('in').addClass('collapse');
        });
    });
});

// Show dropdown menu after clicking mobile nav button
$('#micro-nav-button').on("click", function () {
    var $obj = $('#navbar');

    if (!$obj.hasClass('in')) {
        $obj.animate({'height': '100%'}, function () {
            $obj.addClass('in').removeClass('collapse');
        });
    }
    else {
        $obj.animate({'height': '1px'}, function () {
            $obj.removeClass('in').addClass('collapse');
        });
    }
});

/**
 * Function for back button functionality
 */
$(window).bind('popstate', function (event) {

    var nextUrl = getPage().split(".php")[0];

    switch (nextUrl) {
        case "home":
        case "services":
        case "contact":
            window.currUrl = navUpdate(window.currUrl, nextUrl.toString(), window.pages);

            break;

        default:

            window.currUrl = navUpdate(window.currUrl, "home", window.pages);

    }
    return false;

});

/**
 * Updates the nav link color scheme so that the active link is green. Also updates the history so that the user
 * can still use the back and forward buttons.
 *
 * @param currUrl        url of the currently displayed page
 * @param newPage        url of the user selected page to be displayed
 * @param pages            array with the values being cached selectors for various links and the keys being the requested page
 * @returns {string}    the new page
 */
function navUpdate(currUrl, newPage, pages) {
    pages[currUrl.toString()].removeClass("green");
    pages[currUrl.toString()].removeClass("active");
    pages[currUrl.toString()].addClass("orange");

    pages[newPage.toString()].removeClass("orange");
    pages[newPage.toString()].addClass("active green");

    var pageUrl = newPage.toString() + '-content.php';

    $.get(pageUrl, null, function (result) {
        $("#r-main-content").html(result);
    }, 'html');

    var pageTitle = String();

    switch (newPage) {
        case 'home':
            pageTitle = "";
            break;
        case 'technologies':
            pageTitle = "Technologies";
            break;
        case 'services':
            pageTitle = "Services";
            break;
        case 'contact':
            pageTitle = "Contact";
            break;

        default:
            pageTitle = "Default";
            break;

    }

    pageTitleSelector.html(pageTitle);


    return newPage.toString();

}


// Register navigation selectors in advance
var homeSelector = $("#home-link");
var servicesSelector = $("#services-link");
var contactSelector = $("#contact-link");
var pageTitleSelector = $("#page-title > h3");
var homeContactLinkSelector = $("#contact-link");

var pages = [];
pages["home"] = homeSelector;
pages["services"] = servicesSelector;
pages["contact"] = contactSelector;


// string containing the current page we are on
var currUrl = getPage();
if (currUrl.indexOf('.php') == -1) {
    currUrl = "home";
    currUrl = navUpdate(currUrl, currUrl, pages);
}
else {
    currUrl = currUrl.split('.php');
    currUrl = navUpdate(currUrl[0], currUrl[0], pages); // ensure that page titles are set accordingly on initial load
}


/**
 * Each navigation link is attached a handler that updates the content of the current page with the
 * new page content. In order for the back button to work correctly the pushState function calls had
 * to be placed in each handler instead of in the navUpdate function.
 */
homeSelector.click(function () {

    history.pushState(currUrl, '', 'home.php');

    currUrl = navUpdate(currUrl.toString(), "home", pages);

    return false;
});

servicesSelector.click(function () {

    history.pushState(currUrl, '', 'services.php');
    currUrl = navUpdate(currUrl.toString(), "services", pages);

    return false;
});

contactSelector.click(function () {

    history.pushState(currUrl, '', 'contact.php');
    currUrl = navUpdate(currUrl.toString(), "contact", pages);

    $.getScript("javascript/contact.js");

    return false;
});

